"""
Corporate Number Parser Library
~~~~~~~~~~~~~~~~~~~~~
cnparser is a simple scraping library for Corporate Number Publication Site
"""
from cnparser.load import load, read_csv
from cnparser.enrich import enrich